aboutsummaryrefslogtreecommitdiff
path: root/libjava/java/io/PipedWriter.java
diff options
context:
space:
mode:
Diffstat (limited to 'libjava/java/io/PipedWriter.java')
-rw-r--r--libjava/java/io/PipedWriter.java6
1 files changed, 3 insertions, 3 deletions
diff --git a/libjava/java/io/PipedWriter.java b/libjava/java/io/PipedWriter.java
index e1a2115..e053d55 100644
--- a/libjava/java/io/PipedWriter.java
+++ b/libjava/java/io/PipedWriter.java
@@ -128,21 +128,21 @@ public class PipedWriter extends Writer
* <code>PipedReader</code> to which this object is connected has
* a buffer that cannot hold all of the chars to be written.
*
* @param buf The array containing chars to write to the stream.
* @param offset The index into the array to start writing chars from.
* @param len The number of chars to write.
*
* @exception IOException If the stream has not been connected or has
* been closed.
*/
- public void write(char[] b, int off, int len) throws IOException
+ public void write(char[] buffer, int offset, int len) throws IOException
{
if (sink == null)
throw new IOException ("Not connected");
if (closed)
throw new IOException ("Pipe closed");
- sink.receive (b, off, len);
+ sink.receive(buffer, offset, len);
}
/**
@@ -128,21 +128,21 @@ public class PipedWriter extends Writer
* a buffer that cannot hold all of the chars to be written.
*
- * @param buf The array containing chars to write to the stream.
+ * @param buffer The array containing chars to write to the stream.
* @param offset The index into the array to start writing chars from.
* @param len The number of chars to write.